==> upload-api-client-internal-2.46.0.tgz: package/src/services/UserService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { UserBasicInformation } from "../models/UserBasicInformation";
import type { UserContext } from "../models/UserContext";
import { request as __request } from "../core/request";

export class UserService {
  /**
   * Gets general information about the current user and their accounts, intended to be called at the start of a session
   * in the Upload Dashboard.
   * @returns UserContext Success.
   * @throws ApiError
   */
  public static async context(): Promise<UserContext> {
    const result = await __request({
      method: "GET",
      path: `/v1/users/current/context`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes the current user, permanently deleting any accounts they were the sole administrator of.
   * @returns any Success.
   * @throws ApiError
   */
  public static async deleteCurrentUser(): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/users/current`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates the current user's basic information.
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async updateBasicInformation(requestBody: UserBasicInformation): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/users/current/basic_information`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-2.55.0.tgz: package/src/services/UserService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { UserBasicInformation } from "../models/UserBasicInformation";
import type { UserContext } from "../models/UserContext";
import { request as __request } from "../core/request";

export class UserService {
  /**
   * Gets general information about the current user and their accounts, intended to be called at the start of a session
   * in the Upload Dashboard.
   * @param accountId
   * @returns UserContext Success.
   * @throws ApiError
   */
  public static async context(accountId?: AccountId): Promise<UserContext> {
    const result = await __request({
      method: "GET",
      path: `/v1/users/current/context`,
      query: {
        accountId: accountId
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Deletes the current user, permanently deleting any accounts they were the sole administrator of.
   * @returns any Success.
   * @throws ApiError
   */
  public static async deleteCurrentUser(): Promise<any> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/users/current`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Updates the current user's basic information.
   * @param requestBody
   * @returns any Success.
   * @throws ApiError
   */
  public static async updateBasicInformation(requestBody: UserBasicInformation): Promise<any> {
    const result = await __request({
      method: "PUT",
      path: `/v1/users/current/basic_information`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }
}
